@@ -90,6 +90,8 @@ $code --force --install-extension daohong-emilio.yash
 $code --force --install-extension redhat.vscode-xml
 $code --force --install-extension dotjoshjohnson.xml
 
+# json
+$code --force --install-extension eriklynd.json-tools
 
 
 # git
@@ -174,7 +176,7 @@ $code --force --install-extension vscjava.vscode-java-pack
 # $code --force --install-extension vscjava.vscode-java-dependency
 
 $code --force --install-extension wmanth.jar-viewer
-$code --force --install-extension cracrayol.java-pmd
+#$code --force --install-extension cracrayol.java-pmd # not found
 
 # alternative test runner: 
 # $code --force --install-extension javatest.java-test
@@ -190,7 +192,7 @@ $code --force --install-extension dgileadi.java-decompiler
 
 $code --force --install-extension ryanluker.vscode-coverage-gutters
 
-$code --force --install-extension ithildir.java-properties
+#$code --force --install-extension ithildir.java-properties# not found
 
 echo "install misc" 
 
@@ -205,6 +207,8 @@ $code --force --install-extension tomashubelbauer.email-viewer
 $code --force --install-extension trond-snekvik.simple-rst
 $code --force --install-extension maarti.jenkins-doc
 $code --force --install-extension pdconsec.vscode-print
+$code --force --install-extension oliverkovacs.word-count
+
 
 # something like that i would like for tikz 
 $code --force --install-extension corschenzi.mermaid-graphical-editor
@@ -216,6 +220,14 @@ $code --force --install-extension ms-vscode.extension-test-runner
 
 # rust 
 $code --force --install-extension rust-lang.rust-analyzer
+$code --force --install-extension 1yib.rust-bundle
+$code --force --install-extension dustypomerleau.rust-syntax
+$code --force --install-extension swellaby.rust-pack
+$code --force --install-extension fill-labs.dependi
+
+
+# VHDL
+$code --force --install-extension rjyoung.vscode-modern-vhdl-support
 
 
 source ./instVScode4tex.sh $@
